/* -*-c-*-
 *
 * Messing with X atom properties
 *
 * (c) 2007 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of the Edgeware X tools collection.
 *
 * X tools is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * X tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with X tools; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef LIBXATOM_H
#define LIBXATOM_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Header files ------------------------------------------------------*/

#include <stddef.h>

#include <X11/Xlib.h>

/*----- Functions provided ------------------------------------------------*/

/* --- @xatom_set@ --- *
 *
 * Arguments:	@Display *d@ = pointer to display
 *		@Window w@ = window to set
 *		@Atom p@ = property to set
 *		@Atom a@ = atom property value
 *
 * Returns:	---
 *
 * Use:		Sets an atom property on a particular window.
 */

extern void xatom_set(Display */*d*/, Window /*w*/, Atom /*p*/, Atom /*a*/);

/* --- @xatom_get@ --- *
 *
 * Arguments:	@Display *d@ = pointer to display
 *		@Window w@ = window to set
 *		@Atom p@ = property to read
 *
 * Returns:	Atom which is the value of the property.
 *
 * Use:		Reads an atom property from a particular window.  The value
 *		@None@ is returned if there is no atom value.
 */

extern Atom xatom_get(Display */*d*/, Window /*w*/, Atom /*p*/);

/* --- @xatom_delete@ --- *
 *
 * Arguments:	@Display *d@ = pointer to display
 *		@Window w@ = window containing atom
 *		@Atom p@ = property to delete
 *
 * Returns:	---
 *
 * Use:		Removes a property from a window.
 */

extern void xatom_delete(Display */*d*/, Window /*w*/, Atom /*p*/);

/* --- @xatom_wait@ --- *
 *
 * Arguments:	@Display *d@ = pointer to display
 *		@Window w@ = window to watch
 *		@Atom p@ = property to fetch
 *		@const Atom *aa@ = pointer to vector of atoms
 *		@size_t n@ = numer of atoms in vector
 *
 * Returns:	The matching atom.
 *
 * Use:		Waits for the given property on the window to match one of
 *		the @aa[i]@.
 */

extern Atom xatom_wait(Display */*d*/, Window /*w*/, Atom /*p*/,
		       const Atom */*aa*/, size_t /*n*/);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
